package com.huijy.management.service;

import java.util.List;
import com.huijy.management.domain.AboutUs;

/**
 * 关于我们Service接口
 * 
 * @author luobo
 * @date 2021-09-20
 */
public interface IAboutUsService 
{
    /**
     * 查询关于我们
     * 
     * @param aboutUsId 关于我们主键
     * @return 关于我们
     */
    public AboutUs selectAboutUsByAboutUsId(Long aboutUsId);

    /**
     * 查询关于我们列表
     * 
     * @param aboutUs 关于我们
     * @return 关于我们集合
     */
    public List<AboutUs> selectAboutUsList(AboutUs aboutUs);

    /**
     * 新增关于我们
     * 
     * @param aboutUs 关于我们
     * @return 结果
     */
    public int insertAboutUs(AboutUs aboutUs);

    /**
     * 修改关于我们
     * 
     * @param aboutUs 关于我们
     * @return 结果
     */
    public int updateAboutUs(AboutUs aboutUs);

    /**
     * 批量删除关于我们
     * 
     * @param aboutUsIds 需要删除的关于我们主键集合
     * @return 结果
     */
    public int deleteAboutUsByAboutUsIds(Long[] aboutUsIds);

    /**
     * 删除关于我们信息
     * 
     * @param aboutUsId 关于我们主键
     * @return 结果
     */
    public int deleteAboutUsByAboutUsId(Long aboutUsId);
}
